@@ -3,15 +3,12 @@
 #'
 #'@description Given an integer value X, a cut, that is, edges that are cut will be assigned zero. This cut will be done in the network where the edges have a weight less than the value of X.
 #'
-#'@param x Value that would limit the edges
-#'@param net Network where the edges will be cut
-#'
+#'@param x Integer value that would limit the edges
+#'@param net Complex network where the edges will be cut
 #'
 #'@return Returns the complex network with the cuts already made
 #'
-#' @author Eric Augusto Ito
-#'
-#'
+#'@author Eric Augusto Ito
 #'
 #' @import igraph
 
@@ -25,12 +22,10 @@ threshold <- function(x, net){
 	# 	}
 	# }
 
-	if(x==1){
-
-	}else{
-		matriz<-as_adjacency_matrix(net)
-		matriz[(matriz==(x-1))]<-0
-		net<-graph_from_adjacency_matrix(matriz, mode="undirected")
-	}
-	return(net)
+	if(x!=1){
+ 		matriz<-as_adjacency_matrix(net)
+ 		matriz[(matriz==(x-1))]<-0
+ 		net<-graph_from_adjacency_matrix(matriz, mode="undirected")
+ 	}
+ 	return(net)
 }
\ No newline at end of file
